from setuptools import setup

setup(name='kkpy_gaussbinomial',
      version='1.0',
      description='Gaussian/binomial distributions',
      packages=['kkpy_gaussbinomial'],
      author = 'Kamila Kolpashnikova',
      author_email = 'kamilakolpashnikova@gmail.com',
      zip_safe=False)
